clear
clc
//Programa error_cuad para determinar el error de cuadratura
//Este ejemplo ilustra la exactitud de las rutinas Gaussianas de cuadratura.
//Calcula la integral de exp(x) sobre el dominio [-1,1] utilizando reglas de cuadratura con
//n = 1 a 4.
//El error resultante se compara con reglas de cuadratura cuyos pesos se optimizan pero
//los nodos están igualmente espaciados (no optimizados).
//
//Para la cuadratura Gaussiana:
//Comenzamos con la regla del punto medio(n=1)
format('e',16)
ngq(1)=1;
igq(1)=2*exp(0);
ergq(1)=igq(1)-(exp(1)-exp(-1))
//
//Ahora para la regla de dos puntos:
ngq(2)=2;
igq(2)=exp(-1/3^.5)+exp(1/3^.5);
ergq(2)=igq(2)-(exp(1)-exp(-1))
//
//Ahora para regla de tres puntos:
ngq(3)=3;
igq(3)=8/9.*exp(0)+5/9.*(exp(-0.6^.5)+exp(0.6^.5));
ergq(3)=igq(3)-(exp(1)-exp(-1))
//
//Finalmente la regla de cuatro puntos:
ngq(4)=4;
igq(4)=0.3478548*(exp(-0.8611363)+exp(0.8611363))...
        +0.6521452*(exp(-0.3399810)+exp(0.3399810));
ergq(4)=igq(4)-(exp(1)-exp(-1))
//
figure(1);
plot2d('nl',ngq,abs(ergq))
gca().grid=[1 1 1]
xlabel('Nro. de nodos')
ylabel('Error')
title('Error de Cuadratura de Gauss')
//
//OK, ahora para puntos colocados de manera no óptima, esto es,
//los nodos están igualmente espaciados.
//En este caso comenzamos con n=2 puntos (regla del trapezoide, 
//error de truncamiento = -0.5 (h^3) * f''):
n(1)=2;
i(1)=exp(-1)+exp(1);
er(1)=i(1)-(exp(1)-exp(-1))
//
//Ahora para n=3 (esta es la regla de Simpson 1/3, 
//error de truncamiento = -(1/90)(h^5)* derivada cuarta de f):
n(2)=3;
i(2)=4/3*exp(0)+1/3*(exp(-1)+exp(1));
er(2)=i(2)-(exp(1)-exp(-1))
//
//y para n=4 (regla de Simpson 3/8, 
//error de truncamiento = -(3/80)(h^5)* derivada cuarta de f):
n(3)=4;
i(3)=1/4*(exp(1)+exp(-1))+3/4*(exp(-1/3)+exp(1/3));
er(3)=i(3)-(exp(1)-exp(-1))
//
//Finalmente, para n=5 (regla de Boole,
//error de truncamiento = -(8/945)(h^7)* derivada sexta de f):
n(4)=5;
i(4)=7/45*(exp(-1)+exp(1))+32/45*(exp(-.5)+exp(.5))...
        +12/45*exp(0);
er(4)=i(4)-(exp(1)-exp(-1))
//
nodos_matrix=[n ngq];
error_matrix=[abs(er) abs(ergq)];
figure(2);
plot2d('nl',[nodos_matrix(:,1) nodos_matrix(:,2)],[error_matrix(:,1) error_matrix(:,2)],...
[1:2],leg='Cuadratura con nodos no optimizados@Cuadratura de Gauss')
gca().grid=[1 1 1]
xlabel('Nro de nodos')
ylabel('Error')
title('Comparación de Errores de Cuadratura')
//Como podemos ver, los nodos óptimamente espaciados de la cuadratura Gaussiana permiten
//un cálculo de la integral mucho más exacto que aquel en el que los nodos no están
//óptimamente espaciados.
